Module blaxel.core.client.models.token_rate_metrics
===================================================

Classes
-------

`TokenRateMetrics(token_rate: blaxel.core.client.types.Unset | ForwardRef('TokenRateMetric') = <blaxel.core.client.types.Unset object>, token_rate_input: blaxel.core.client.types.Unset | ForwardRef('TokenRateMetric') = <blaxel.core.client.types.Unset object>, token_rate_output: blaxel.core.client.types.Unset | ForwardRef('TokenRateMetric') = <blaxel.core.client.types.Unset object>)`
:   Token rate metrics
    
    Attributes:
        token_rate (Union[Unset, TokenRateMetric]): Token rate metric
        token_rate_input (Union[Unset, TokenRateMetric]): Token rate metric
        token_rate_output (Union[Unset, TokenRateMetric]): Token rate metric
    
    Method generated by attrs for class TokenRateMetrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `token_rate`
    :

    `token_rate_input`
    :

    `token_rate_output`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :